@@ -4,11 +4,17 @@ import os
 import shutil
 from functools import wraps
 from pathlib import Path
-from typing import Optional, Union, Dict
+from typing import Optional, Union, Dict, MutableMapping
 
 import yaml
 
-from autoconf.directory_config import RecursiveConfig, PriorConfigWrapper, AbstractConfig, family
+from autoconf.directory_config import (
+    RecursiveConfig,
+    PriorConfigWrapper,
+    AbstractConfig,
+    family,
+)
+from autoconf.exc import ConfigException
 from autoconf.json_prior.config import JSONPriorConfig
 
 logger = logging.getLogger(__name__)
@@ -23,7 +29,16 @@ def get_matplotlib_backend():
         return "default"
 
 
-class DictWrapper:
+class DictWrapper(MutableMapping):
+    def __delitem__(self, v) -> None:
+        del self._dict[v]
+
+    def __len__(self) -> int:
+        return len(self._dict)
+
+    def __iter__(self):
+        return iter(self._dict)
+
     def __init__(self, paths):
         self._dict = dict()
         self.paths = paths
@@ -45,15 +60,11 @@ class DictWrapper:
         try:
             return self._dict[key]
         except KeyError:
-            raise KeyError(
-                f"key {key} not found in paths {self.paths_string}"
-            )
+            raise KeyError(f"key {key} not found in paths {self.paths_string}")
 
     @property
     def paths_string(self):
-        return "\n".join(
-            map(str, self.paths)
-        )
+        return "\n".join(map(str, self.paths))
 
     def __repr__(self):
         return repr(self._dict)
@@ -97,15 +108,12 @@ class Config:
                     f"{config_path} passed as config path. Did you mean to use output_path={config_path}?"
                 )
 
-        self._configs = list()
-        self._dict = DictWrapper(
-            self.paths
-        )
+        self._prior_config = None
 
-        self.configs = list(map(
-            RecursiveConfig,
-            config_paths
-        ))
+        self._configs = list()
+        self._dict = DictWrapper(self.paths)
+
+        self.configs = list(map(RecursiveConfig, config_paths))
 
         self.output_path = output_path
 
@@ -117,28 +125,15 @@ class Config:
         Lazily recurse directories to load configuration.
         """
         if self._dict is None:
-            self._dict = DictWrapper(
-                self.paths
-            )
+            self._dict = DictWrapper(self.paths)
 
-            def recurse_config(
-                    config,
-                    d
-            ):
+            def recurse_config(config, d):
                 try:
                     for key, value in config.items():
-                        if isinstance(
-                                value,
-                                AbstractConfig
-                        ):
+                        if isinstance(value, AbstractConfig):
                             if key not in d:
-                                d[key] = DictWrapper(
-                                    self.paths
-                                )
-                            recurse_config(
-                                value,
-                                d=d[key]
-                            )
+                                d[key] = DictWrapper(self.paths)
+                            recurse_config(value, d=d[key])
                         else:
                             d[key] = value
                 except KeyError as e:
@@ -154,9 +149,7 @@ class Config:
         """
         logging_config = self.logging_config
         if logging_config is not None:
-            logging.config.dictConfig(
-                logging_config
-            )
+            logging.config.dictConfig(logging_config)
 
     @property
     def logging_config(self) -> Optional[Dict]:
@@ -168,17 +161,11 @@ class Config:
         for config in self.configs:
             path = config.path
             try:
-                if LOGGING_CONFIG_FILE in os.listdir(
-                        config.path
-                ):
-                    with open(
-                            path / LOGGING_CONFIG_FILE
-                    ) as f:
+                if LOGGING_CONFIG_FILE in os.listdir(config.path):
+                    with open(path / LOGGING_CONFIG_FILE) as f:
                         return yaml.safe_load(f)
             except FileNotFoundError:
-                logger.debug(
-                    f"No configuration found at path {config.path}"
-                )
+                logger.debug(f"No configuration found at path {config.path}")
         return None
 
     @property
@@ -191,19 +178,19 @@ class Config:
         When the list of configs is updated this invalidates the current config
         dictionary
         """
+        self._prior_config = None
         self._dict = None
         self._configs = configs
 
     def __getitem__(self, item):
         return self.dict[item]
 
+    def __iter__(self):
+        return iter(self.dict)
+
     @property
     def paths(self):
-        return [
-            config.path
-            for config
-            in self._configs
-        ]
+        return [config.path for config in self._configs]
 
     @property
     def prior_config(self) -> PriorConfigWrapper:
@@ -211,18 +198,17 @@ class Config:
         Configuration for priors. This indicates, for example, the mean and the width of priors
         for the attributes of given classes.
         """
-        return PriorConfigWrapper([
-            JSONPriorConfig.from_directory(
-                path / "priors"
+        if self._prior_config is None:
+            self._prior_config = PriorConfigWrapper(
+                [JSONPriorConfig.from_directory(path / "priors") for path in self.paths]
             )
-            for path in self.paths
-        ])
+        return self._prior_config
 
     def push(
-            self,
-            new_path: Union[str, Path],
-            output_path: Optional[str] = None,
-            keep_first: bool = False
+        self,
+        new_path: Union[str, Path],
+        output_path: Optional[str] = None,
+        keep_first: bool = False,
     ):
         """
         Push a new configuration path. This overrides the existing config
@@ -238,25 +224,47 @@ class Config:
             unchanged
         keep_first
             If True the current priority configuration mains such.
+
+        Raises
+        ------
+        ConfigException
+            If the pushed path does not exist or does not contain at least one file
+            with an expected configuration suffix
         """
-        logger.debug(
-            f"Pushing new config with path {new_path}"
-        )
+        logger.debug(f"Pushing new config with path {new_path}")
+
+        if not Path(new_path).exists():
+            raise ConfigException(f"{new_path} does not exist")
+
+        suffixes = {
+            Path(file).suffix for _, _, files in os.walk(new_path) for file in files
+        }
+
+        CONFIG_SUFFIXES = [
+            ".yml",
+            ".ini",
+            ".json",
+            ".yaml",
+        ]
+
+        if not any((suffix in suffixes for suffix in CONFIG_SUFFIXES)):
+            raise ConfigException(
+                f"{new_path} does not contain any files ending with {'/'.join(CONFIG_SUFFIXES)} recursively"
+            )
 
         self.output_path = output_path or self.output_path
 
-        if self.configs[0] == new_path or (
+        try:
+            if self.configs[0] == new_path or (
                 keep_first and len(self.configs) > 1 and self.configs[1] == new_path
-        ):
-            return
-        new_config = RecursiveConfig(
-            new_path
-        )
+            ):
+                return
+        except IndexError:
+            pass
 
-        configs = list(filter(
-            lambda config: config != new_config,
-            self.configs
-        ))
+        new_config = RecursiveConfig(new_path)
+
+        configs = list(filter(lambda config: config != new_config, self.configs))
         if keep_first:
             self.configs = configs[:1] + [new_config] + configs[1:]
         else:
@@ -273,26 +281,19 @@ class Config:
         file
             The path to the project's __init__
         """
-        self.push(
-            Path(file).parent / "config",
-            keep_first=True
-        )
+        self.push(Path(file).parent / "config", keep_first=True)
 
 
 current_directory = Path(os.getcwd())
 
 default = Config(
-    current_directory / "config",
-    output_path=current_directory / "output/"
+    current_directory / "config", output_path=current_directory / "output/"
 )
 
 instance = default
 
 
-def output_path_for_test(
-        temporary_path="temp",
-        remove=True
-):
+def output_path_for_test(temporary_path="temp", remove=True):
     """
     Temporarily change the output path for the scope of a function
     (e.g. a test). Remove the files after the test has completed
@@ -312,10 +313,7 @@ def output_path_for_test(
 
     def remove_():
         if remove:
-            shutil.rmtree(
-                temporary_path,
-                ignore_errors=True
-            )
+            shutil.rmtree(temporary_path, ignore_errors=True)
 
     def decorator(func):
         @wraps(func)
