@@ -5,7 +5,7 @@ class Redshift:
 
 class SphProfile:
     def __init__(self, centre=(0.0, 0.0)):
-        """ Generic circular profiles class to contain functions shared by light and
+        """Generic circular profiles class to contain functions shared by light and
         mass profiles.
 
         Parameters
@@ -18,7 +18,7 @@ class SphProfile:
 
 class EllProfile(SphProfile):
     def __init__(self, centre=(0.0, 0.0), axis_ratio=1.0, phi=0.0):
-        """ Generic elliptical profiles class to contain functions shared by light
+        """Generic elliptical profiles class to contain functions shared by light
         and mass profiles.
 
         Parameters
@@ -35,11 +35,11 @@ class EllProfile(SphProfile):
         self.phi = phi
 
 
-class EllGaussian(EllProfile):
+class Gaussian(EllProfile):
     def __init__(
-            self, centre=(0.0, 0.0), axis_ratio=1.0, phi=0.0, intensity=0.1, sigma=0.01
+        self, centre=(0.0, 0.0), axis_ratio=1.0, phi=0.0, intensity=0.1, sigma=0.01
     ):
-        """ The elliptical Gaussian profile.
+        """The elliptical Gaussian profile.
 
         Parameters
         ----------
@@ -55,7 +55,7 @@ class EllGaussian(EllProfile):
         sigma
             The full-width half-maximum of the Gaussian.
         """
-        super(EllGaussian, self).__init__(centre, axis_ratio, phi)
+        super(Gaussian, self).__init__(centre, axis_ratio, phi)
 
         self.intensity = intensity
         self.sigma = sigma
